EditorInsertText class

Notify the editor to insert some text.

Inheritance

Constructors

EditorInsertText({required String payload})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
method → String
The summernote API method to call.
finalinherited
payload → String?
The data which should be passed to the editor.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant EditorEvent other) → bool
The equality operator.
inherited