EditorMessage class

A DTO representing a message transferred between dart and javascript.

Constructors

EditorMessage({required String key, String type = "toDart", required String method, String? payload})
Build a message.
const
EditorMessage.fromEvent({required String key, required EditorEvent event, String type = "toSummernote"})
factory
EditorMessage.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
key → String
The id of the HtmlElementView.
final
method → String
The method used for the message.
final
payload → String?
The payload of the message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the message.
final

Methods

copyWith({String? key, String? type, String? method, String? payload}) → EditorMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant EditorMessage other) → bool
The equality operator.
override